==> lucene-core-9.0.1-20220208.204806-8-sources.jar: org/apache/lucene/util/hnsw/BoundsChecker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.lucene.util.hnsw;

abstract class BoundsChecker {

  float bound;

  /** Update the bound if sample is better */
  abstract void update(float sample);

  /** Update the bound unconditionally */
  void set(float sample) {
    bound = sample;
  }

  /** @return whether the sample exceeds (is worse than) the bound */
  abstract boolean check(float sample);

  static BoundsChecker create(boolean reversed) {
    if (reversed) {
      return new Min();
    } else {
      return new Max();
    }
  }

  static class Max extends BoundsChecker {
    Max() {
      bound = Float.NEGATIVE_INFINITY;
    }

    @Override
    void update(float sample) {
      if (sample > bound) {
        bound = sample;
      }
    }

    @Override
    boolean check(float sample) {
      return sample < bound;
    }
  }

  static class Min extends BoundsChecker {

    Min() {
      bound = Float.POSITIVE_INFINITY;
    }

    @Override
    void update(float sample) {
      if (sample < bound) {
        bound = sample;
      }
    }

    @Override
    boolean check(float sample) {
      return sample > bound;
    }
  }
}

==> lucene-core-9.2.1-20220525.125616-4-sources.jar: org/apache/lucene/util/hnsw/BoundsChecker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.lucene.util.hnsw;

/**
 * A helper class for an hnsw graph that serves as a comparator of the currently set bound value
 * with a new value.
 */
public abstract class BoundsChecker {

  float bound;

  /** Update the bound if sample is better */
  public abstract void update(float sample);

  /** Update the bound unconditionally */
  public void set(float sample) {
    bound = sample;
  }

  /** @return whether the sample exceeds (is worse than) the bound */
  public abstract boolean check(float sample);

  public static BoundsChecker create(boolean reversed) {
    if (reversed) {
      return new Min();
    } else {
      return new Max();
    }
  }

  /**
   * A helper class for an hnsw graph that serves as a comparator of the currently set maximum value
   * with a new value.
   */
  public static class Max extends BoundsChecker {
    Max() {
      bound = Float.NEGATIVE_INFINITY;
    }

    @Override
    public void update(float sample) {
      if (sample > bound) {
        bound = sample;
      }
    }

    @Override
    public boolean check(float sample) {
      return sample < bound;
    }
  }

  /**
   * A helper class for an hnsw graph that serves as a comparator of the currently set minimum value
   * with a new value.
   */
  public static class Min extends BoundsChecker {

    Min() {
      bound = Float.POSITIVE_INFINITY;
    }

    @Override
    public void update(float sample) {
      if (sample < bound) {
        bound = sample;
      }
    }

    @Override
    public boolean check(float sample) {
      return sample > bound;
    }
  }
}
